@@ -16,27 +16,28 @@ public class TabResource implements Serializable {
 
 	private static final long serialVersionUID = -8353499109124097114L;
 
-	protected TRId trId;
-	protected String id;// For grid only
-	protected String name;
-	protected String description;
-	protected String agency;
-	protected String date;
-	protected String right;
-	protected String validFrom;
-	protected String validUntilTo;
-	protected String licence;
-	protected Contacts owner;
-	protected ArrayList<Contacts> contacts;
-	protected boolean valid;
-	protected boolean finalized;
-	protected boolean locked;
+	private TRId trId;
+	private String id;// For grid only
+	private String name;
+	private String description;
+	private String agency;
+	private String date;
+	private String right;
+	private String validFrom;
+	private String validUntilTo;
+	private String licence;
+	private Contacts owner;
+	private ArrayList<Contacts> contacts;
+	private boolean valid;
+	private boolean finalized;
+	private boolean locked;
 	
 	public TabResource() {
 	}
 
 	public TabResource(String id, String name, String description,
-			String agency, String date, String right, String validFrom, String validUntilTo, String licence, TRId trId) {
+			String agency, String date, String right, String validFrom, String validUntilTo, 
+			String licence, TRId trId) {
 		this.id = id;
 		this.name = name;
 		this.description = description;
